package com.sooka.sponest.monitor.meiqiguan.gps.service;

import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.sooka.sponest.monitor.meiqiguan.gps.domain.GasTankDevices;
import com.sooka.sponest.monitor.meiqiguan.gps.domain.vo.GasTankDevicesVo;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2023-12-09
 */
public interface IGasTankDevicesService {

    /**
     * 查询煤气罐设备信息
     *
     * @param id 煤气罐设备信息主键
     * @return 煤气罐设备信息
     */
    public GasTankDevices selectGasTankDevicesById(Long id);

    /**
     * 查询煤气罐设备信息列表
     *
     * @param gasTankDevices 煤气罐设备信息
     * @return 煤气罐设备信息集合
     */
    public List<GasTankDevices> selectGasTankDevicesList(GasTankDevices gasTankDevices);


    public List<GasTankDevices> selectGasTankDevicesListDpet(List<String> gps);

    /**
     * 新增煤气罐设备信息
     *
     * @param gasTankDevices 煤气罐设备信息
     * @return 结果
     */
    public int insertGasTankDevices(GasTankDevices gasTankDevices);

    /**
     * 修改煤气罐设备信息
     *
     * @param gasTankDevices 煤气罐设备信息
     * @return 结果
     */
    public int updateGasTankDevices(GasTankDevices gasTankDevices);

    /**
     * 批量删除煤气罐设备信息
     *
     * @param ids 需要删除的煤气罐设备信息主键集合
     * @return 结果
     */
    public int deleteGasTankDevicesByIds(Long[] ids);

    /**
     * 删除煤气罐设备信息信息
     *
     * @param id 煤气罐设备信息主键
     * @return 结果
     */
    public int deleteGasTankDevicesById(Long id);

    List<GasTankDevicesVo> selectGasTankDevicesListAll(GasTankDevices gasTankDevices);

    List<GasTankDevices> selectGasTankDevicesNewEndTime();
}
